﻿using System;
using System.Collections.ObjectModel;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;

namespace post4815
{
    public partial class _Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
                Map1.CurrentExtent = new RectangleShape(-121.82285, 50.64012, -87.58945, 25.1518);
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(MapPath("~/App_Data/STATES.SHP"));
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 243, 239, 228), GeoColor.FromArgb(255, 218, 193, 163), 1);
                worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                InMemoryFeatureLayer highlightLayer = new InMemoryFeatureLayer();
                highlightLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.Capital2;
                highlightLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Evergreen1;
                highlightLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                Map1.StaticOverlay.Layers.Add("WorldLayer", worldLayer);
                Map1.DynamicOverlay.Layers.Add("HighlightLayer", highlightLayer);
            }
        }

        protected void Map1_Click(object sender, ThinkGeo.MapSuite.WebEdition.MapClickedEventArgs e)
        {
            ViewState["CenterPoint"] = e.Position;
            FindFeaturesNearestTo();
        }

        private void FindFeaturesNearestTo()
        {
            PointShape pointShape = (PointShape)ViewState["CenterPoint"];
            FeatureLayer worldLayer = (FeatureLayer)Map1.StaticOverlay.Layers["WorldLayer"];
            InMemoryFeatureLayer highlightLayer = (InMemoryFeatureLayer)Map1.DynamicOverlay.Layers["HighlightLayer"];

            worldLayer.Open();
            Collection<Feature> features = worldLayer.QueryTools.GetFeaturesNearestTo(pointShape, GeographyUnit.DecimalDegree, 2, new string[] { "STATE_NAME" });
            worldLayer.Close();

            if (highlightLayer.InternalFeatures.Count > 0)
            {
                highlightLayer.InternalFeatures.Clear();
            }

            highlightLayer.InternalFeatures.Add("Point", new Feature(pointShape));
            foreach (Feature feature in features)
            {
                highlightLayer.InternalFeatures.Add(feature.Id, feature);
            }

            Map1.DynamicOverlay.Redraw();
        }
    }
}
